@@ -64,15 +64,27 @@ log = logging.getLogger('Terminal')
 log.setLevel(logging.DEBUG)
 logging.basicConfig()
 
-FONT_SIZE = 10
+try:
+    olpc_build = file('/boot/olpc_build', 'r').readline()
+except:
+    olpc_build = ''
+
+if olpc_build.startswith('13'):
+    FONT_SIZE = 8
+else:
+    FONT_SIZE = 12
 
 VTE_VERSION = 0
 try:
     VTE_VERSION = Vte.MINOR_VERSION
 except:
-    # version is not published in old versions of vte
+    # version is not published in some versions of vte, notably 2.90
     pass
 
+if VTE_VERSION == 0:
+    if hasattr(Vte, '_version'):
+        major, minor = Vte._version.split('.')
+        VTE_VERSION = minor
 
 class TerminalActivity(activity.Activity):
 
